@@ -1,6 +1,5 @@
 import math
 
-
 class Colour:
 	def __init__(self, red=0, green=0, blue=0):
 		if type(red) == str:
@@ -11,6 +10,10 @@ class Colour:
 			self.green = green
 			self.blue = blue
 			self.hex = rgb_to_hex(red, green, blue)
+	def __repr__(self):
+		return self.hex
+	def __str__(self):
+		return self.hex
 
 def rgb_to_hex(red, green, blue):
 	decimal_hex_map = ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "a", "b", "c", "d", "e", "f"]
@@ -25,3 +28,11 @@ def hex_to_rgb(hex):
 	blue = hex_decimal_map[hex[5]] * 16 + hex_decimal_map[hex[6]]
 	return (red, green, blue)
 
+WHITE = Colour("#ffffff")
+BLACK = Colour("#000000")
+BLUE = Colour("#0000ff")
+RED = Colour("#ff0000")
+GREEN = Colour("#00ff00")
+YELLOW = Colour("#ffff00")
+CYAN = Colour("#00ffff")
+MAGENTA = Colour("#ff00ff")
